@@ -1,6 +1,6 @@
 canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL, 
-    Y, K, numchain, simrun, writeskip, projectname, cell.line = NULL,
-    diagnostics = NULL, plot.likelihood = NULL) {
+    Y, K, numchain, max.simrun, min.simrun, writeskip, projectname, 
+    cell.line = NULL, plot.likelihood = NULL) {
     if (!is.matrix(R)) {
         stop("R should be a matrix!")
     }
@@ -19,9 +19,6 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
     if (is.null(cell.line)) {
         cell.line = FALSE
     }
-    if (is.null(diagnostics)) {
-        diagnostics = FALSE
-    }
     if (is.null(plot.likelihood)) {
         plot.likelihood = TRUE
     }
@@ -32,6 +29,10 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
     if (any(colSums(C) != 1)) {
         stop("Matrix C should have one and only one 1 for each column!")
     }
+    if ( plot.likelihood){
+        pdf(file = paste(projectname, "_likelihood.pdf", sep = ""), width = 10, height = 5)
+    }
+    
     sampname = colnames(R)
     sna.name = rownames(R)
     cna.region.name = rownames(C)
@@ -41,7 +42,9 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
     for (k in K) {
         cat("Sample in tree space with", k, "subclones\n")
         sampchaink = vector("list", numchain)
-        for (numi in 1:numchain) {
+        sampchaink.lik=vector('list',numchain)
+        sampchaink.accept.rate=vector('list',numchain)
+        for (numi in 1:numchain) {  # numi: number of chain
             cat("\tRunning chain", numi, "out of", numchain, "...\n")
             ###################################### Tree initialization #####
             text = paste(paste(paste(paste("(", 1:(k - 1), ",", sep = ""), 
@@ -80,9 +83,12 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
             ###################################### Sample in tree space #####
             sampi = 1
             writei = 1
-            samptree = vector("list", simrun)
-            while (sampi <= simrun) {
-                # sample sna positions
+            samptree = vector("list", max.simrun)
+            samptree.lik=rep(NA, max.simrun)
+            samptree.accept=rep(NA, max.simrun)
+            samptree.accept.rate=rep(NA, max.simrun)
+            while (sampi <= max.simrun) {  # sampi: MCMC iteration number
+                ######### sample sna positions
                 tree.new = tree
                 tree.new$sna = sampsna(tree)
                 tree.new$Z = getZ(tree.new, sna.name)
@@ -91,13 +97,20 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
                 tree.new$VAF = getVAF(tree.new, Y)
                 tree.new$likelihood = getlikelihood(tree.new, R, X, 
                   WM, Wm, epsilonM, epsilonm)
-                tree = addsamptree(tree, tree.new, diagnostics)
+                tree.temp=addsamptree(tree,tree.new)
+                tree=tree.temp[[1]]
+                samptree.accept[sampi]=tree.temp[[2]]
                 if (sampi%%writeskip == 0) {
                   samptree[[writei]] = tree
                   writei = writei + 1
                 }
+                samptree.lik[sampi]=tree$likelihood
+                samptree.accept.rate[sampi]=mean(samptree.accept[max(1,sampi-999):sampi])
+                if ((sampi >= 2*min.simrun) & (samptree.lik[sampi] <= mean(samptree.lik[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= mean(samptree.accept.rate[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= 0.1)) break
                 sampi = sampi + 1
-                # sample cna positions
+                ######## sample cna positions
                 tree.new = tree
                 tree.new$cna = sampcna(tree)
                 CMCm = getCMCm(tree.new, C)
@@ -108,25 +121,39 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
                 tree.new$VAF = getVAF(tree.new, Y)
                 tree.new$likelihood = getlikelihood(tree.new, R, X, 
                   WM, Wm, epsilonM, epsilonm)
-                tree = addsamptree(tree, tree.new, diagnostics)
+                tree.temp=addsamptree(tree,tree.new)
+                tree=tree.temp[[1]]
+                samptree.accept[sampi]=tree.temp[[2]]
                 if (sampi%%writeskip == 0) {
                   samptree[[writei]] = tree
                   writei = writei + 1
                 }
+                samptree.lik[sampi]=tree$likelihood
+                samptree.accept.rate[sampi]=mean(samptree.accept[max(1,sampi-999):sampi])
+                if ((sampi >= 2*min.simrun) & (samptree.lik[sampi] <= mean(samptree.lik[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= mean(samptree.accept.rate[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= 0.1)) break
                 sampi = sampi + 1
-                # sample P (clonal proportions)
+                ######## sample P (clonal proportions)
                 tree.new = tree
                 tree.new$P = sampP(tree.new, cell.line)
                 tree.new$VAF = getVAF(tree.new, Y)
                 tree.new$likelihood = getlikelihood(tree.new, R, X, 
                   WM, Wm, epsilonM, epsilonm)
-                tree = addsamptree(tree, tree.new, diagnostics)
+                tree.temp=addsamptree(tree,tree.new)
+                tree=tree.temp[[1]]
+                samptree.accept[sampi]=tree.temp[[2]]
                 if (sampi%%writeskip == 0) {
                   samptree[[writei]] = tree
                   writei = writei + 1
                 }
+                samptree.lik[sampi]=tree$likelihood
+                samptree.accept.rate[sampi]=mean(samptree.accept[max(1,sampi-999):sampi])
+                if ((sampi >= 2*min.simrun) & (samptree.lik[sampi] <= mean(samptree.lik[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= mean(samptree.accept.rate[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= 0.1)) break
                 sampi = sampi + 1
-                # sample major and minor copy number
+                ######## sample major and minor copy number
                 tree.new = tree
                 tree.new$cna.copy = sampcnacopy(tree.new)
                 CMCm = getCMCm(tree.new, C)
@@ -135,13 +162,20 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
                 tree.new$VAF = getVAF(tree.new, Y)
                 tree.new$likelihood = getlikelihood(tree.new, R, X, 
                   WM, Wm, epsilonM, epsilonm)
-                tree = addsamptree(tree, tree.new, diagnostics)
+                tree.temp=addsamptree(tree,tree.new)
+                tree=tree.temp[[1]]
+                samptree.accept[sampi]=tree.temp[[2]]
                 if (sampi%%writeskip == 0) {
                   samptree[[writei]] = tree
                   writei = writei + 1
                 }
+                samptree.lik[sampi]=tree$likelihood
+                samptree.accept.rate[sampi]=mean(samptree.accept[max(1,sampi-999):sampi])
+                if ((sampi >= 2*min.simrun) & (samptree.lik[sampi] <= mean(samptree.lik[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= mean(samptree.accept.rate[max((sampi-1000),1):max((sampi-1),1)])) &
+                    (samptree.accept.rate[sampi] <= 0.1)) break
                 sampi = sampi + 1
-                # sample whether SNA falls in major or minor allele
+                ######## sample whether SNA falls in major or minor allele
                 if (any(tree$Q == 1)) {
                   tree.new = tree
                   q.temp = which(tree.new$Q == 1)
@@ -150,22 +184,56 @@ canopy.sample = function(R, X, WM, Wm, epsilonM, epsilonm, C = NULL,
                   tree.new$VAF = getVAF(tree.new, Y)
                   tree.new$likelihood = getlikelihood(tree.new, R, X, 
                     WM, Wm, epsilonM, epsilonm)
-                  tree = addsamptree(tree, tree.new, diagnostics)
+                  tree.temp=addsamptree(tree,tree.new)
+                  tree=tree.temp[[1]]
+                  samptree.accept[sampi]=tree.temp[[2]]
                   if (sampi%%writeskip == 0) {
                     samptree[[writei]] = tree
                     writei = writei + 1
                   }
+                  samptree.lik[sampi]=tree$likelihood
+                  samptree.accept.rate[sampi]=mean(samptree.accept[max(1,sampi-999):sampi])
+                  if ((sampi >= 2*min.simrun) & (samptree.lik[sampi] <= mean(samptree.lik[max((sampi-1000),1):max((sampi-1),1)])) &
+                      (samptree.accept.rate[sampi] <= mean(samptree.accept.rate[max((sampi-1000),1):max((sampi-1),1)])) &
+                      (samptree.accept.rate[sampi] <= 0.1)) break
                   sampi = sampi + 1
                 }
             }
             sampchaink[[numi]] = samptree[1:(writei - 1)]
+            sampchaink.lik[[numi]]=samptree.lik
+            sampchaink.accept.rate[[numi]]=samptree.accept.rate
         }
         ###################################### plotting and saving #####
         if (plot.likelihood) {
-            plotpostlikelihood(sampchaink, projectname, k, numchain)
+            par(mfrow=c(1,2))
+            xmax=ymin=ymax=rep(NA,numchain)
+            for(i in 1:numchain){
+                xmax[i]=max(which((!is.na(sampchaink.lik[[i]]))))
+                ymin[i]=sampchaink.lik[[i]][1]
+                ymax[i]=sampchaink.lik[[i]][xmax[i]]
+            }
+            
+            plot(sampchaink.lik[[1]],xlim=c(1,max(xmax)),ylim=c(min(ymin),max(ymax)),
+                 xlab='Iteration',ylab='Log-likelihood',type='l',
+                 main=paste('Post. likelihood:',k,'branches'))
+            for(numi in 2:numchain){
+                points(sampchaink.lik[[numi]],xlim=c(1,max(xmax)),ylim=c(min(ymin),max(ymax)),col=numi,type='l')
+            }
+            
+            plot(sampchaink.accept.rate[[1]],ylim=c(0,1),xlim=c(1,max(xmax)),
+                 xlab='Iteration',ylab='Acceptance rate',type='l',
+                 main=paste('Acceptance rate:',k,'branches'))
+            for(numi in 2:numchain){
+                points(sampchaink.accept.rate[[numi]],ylim=c(0,1),xlim=c(1,max(xmax)),col=numi,type='l')
+            }
+            par(mfrow=c(1,1))
         }
         sampchain[[ki]] = sampchaink
+        
         ki = ki + 1
     }
+    if(plot.likelihood) {
+        dev.off()
+    }
     return(sampchain)
 } 
