@@ -7,8 +7,7 @@ getZ = function(tree, sna.name) {
     clonal.sna = vector("list", k)
     for (tip in 2:k) {
         child.node = tip
-        parent.node = tree$edge[which(tree$edge[, 2] == child.node), 
-            1]
+        parent.node = tree$edge[which(tree$edge[, 2] == child.node), 1]
         while (parent.node >= (k + 1)) {
             snatemp = intersect(which(tree$sna[, 2] == parent.node), 
                 which(tree$sna[, 3] == child.node))
@@ -18,17 +17,12 @@ getZ = function(tree, sna.name) {
             child.node = parent.node
             if (child.node == (k + 1)) 
                 break
-            parent.node = tree$edge[which(tree$edge[, 2] == child.node), 
-                1]
+            parent.node = tree$edge[which(tree$edge[, 2] == child.node), 1]
         }
     }
     clonal.sna[[1]] = 0
-    for (k in 2:k) {
-        for (s in 1:s) {
-            if (is.element(s, clonal.sna[[k]])) {
-                Z[s, k] = 1
-            }
-        }
+    for (ki in 2:k) {
+        Z[clonal.sna[[ki]],ki]=1
     }
     return(Z)
-} 
+}
