@@ -4,7 +4,6 @@ sampcna = function(tree) {
     cna.change = sample.int(sample.int(1, n = t), n = t)
     cna.edge = sample(2:nrow(tree$edge), size = length(cna.change), 
         replace = TRUE)
-    cna[cna.change, 2] = tree$edge[cna.edge, 1]
-    cna[cna.change, 3] = tree$edge[cna.edge, 2]
+    cna[cna.change, 2:3] = tree$edge[cna.edge, 1:2]
     return(cna)
 } 
